==> libsocialweb-0.25.7.tar.bz2: libsocialweb-0.25.7/interfaces/sw-marshals.h <==

#ifndef __sw_marshal_MARSHAL_H__
#define __sw_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:BOXED,POINTER (sw-marshals.list:1) */
extern void sw_marshal_VOID__BOXED_POINTER (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* VOID:STRING,INT64,BOXED (sw-marshals.list:2) */
extern void sw_marshal_VOID__STRING_INT64_BOXED (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:STRING,STRING,INT64,BOXED (sw-marshals.list:3) */
extern void sw_marshal_VOID__STRING_STRING_INT64_BOXED (GClosure     *closure,
                                                        GValue       *return_value,
                                                        guint         n_param_values,
                                                        const GValue *param_values,
                                                        gpointer      invocation_hint,
                                                        gpointer      marshal_data);

/* VOID:STRING,STRING (sw-marshals.list:4) */
extern void sw_marshal_VOID__STRING_STRING (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* VOID:BOXED,UINT,POINTER (sw-marshals.list:5) */
extern void sw_marshal_VOID__BOXED_UINT_POINTER (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:STRING,POINTER (sw-marshals.list:6) */
extern void sw_marshal_VOID__STRING_POINTER (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

/* VOID:STRING,BOXED (sw-marshals.list:7) */
extern void sw_marshal_VOID__STRING_BOXED (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);

/* VOID:BOXED,BOXED (sw-marshals.list:8) */
extern void sw_marshal_VOID__BOXED_BOXED (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);

/* VOID:BOOLEAN,BOOLEAN,BOOLEAN (sw-marshals.list:9) */
extern void sw_marshal_VOID__BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                      GValue       *return_value,
                                                      guint         n_param_values,
                                                      const GValue *param_values,
                                                      gpointer      invocation_hint,
                                                      gpointer      marshal_data);

/* VOID:POINTER (sw-marshals.list:10) */
#define sw_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER

/* VOID:STRING,STRING,STRING,UINT,UINT,STRING,POINTER (sw-marshals.list:11) */
extern void sw_marshal_VOID__STRING_STRING_STRING_UINT_UINT_STRING_POINTER (GClosure     *closure,
                                                                            GValue       *return_value,
                                                                            guint         n_param_values,
                                                                            const GValue *param_values,
                                                                            gpointer      invocation_hint,
                                                                            gpointer      marshal_data);

/* VOID:STRING,STRING,STRING,INT64,STRING,STRING,UINT,UINT,STRING,POINTER (sw-marshals.list:12) */
extern void sw_marshal_VOID__STRING_STRING_STRING_INT64_STRING_STRING_UINT_UINT_STRING_POINTER (GClosure     *closure,
                                                                                                GValue       *return_value,
                                                                                                guint         n_param_values,
                                                                                                const GValue *param_values,
                                                                                                gpointer      invocation_hint,
                                                                                                gpointer      marshal_data);

/* VOID:STRING,BOXED,POINTER (sw-marshals.list:13) */
extern void sw_marshal_VOID__STRING_BOXED_POINTER (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

/* VOID:INT,INT,STRING (sw-marshals.list:14) */
extern void sw_marshal_VOID__INT_INT_STRING (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

G_END_DECLS

#endif /* __sw_marshal_MARSHAL_H__ */

==> libsocialweb_0.25.20.orig.tar.bz2: libsocialweb-0.25.20/interfaces/sw-marshals.h <==

#ifndef __sw_marshal_MARSHAL_H__
#define __sw_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:BOXED,POINTER (sw-marshals.list:1) */
extern void sw_marshal_VOID__BOXED_POINTER (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* VOID:STRING,INT64,BOXED (sw-marshals.list:2) */
extern void sw_marshal_VOID__STRING_INT64_BOXED (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:STRING,STRING,INT64,BOXED (sw-marshals.list:3) */
extern void sw_marshal_VOID__STRING_STRING_INT64_BOXED (GClosure     *closure,
                                                        GValue       *return_value,
                                                        guint         n_param_values,
                                                        const GValue *param_values,
                                                        gpointer      invocation_hint,
                                                        gpointer      marshal_data);

/* VOID:STRING,STRING (sw-marshals.list:4) */
extern void sw_marshal_VOID__STRING_STRING (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* VOID:BOXED,UINT,POINTER (sw-marshals.list:5) */
extern void sw_marshal_VOID__BOXED_UINT_POINTER (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:STRING,POINTER (sw-marshals.list:6) */
extern void sw_marshal_VOID__STRING_POINTER (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

/* VOID:STRING,BOXED (sw-marshals.list:7) */
extern void sw_marshal_VOID__STRING_BOXED (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);

/* VOID:BOXED,BOXED (sw-marshals.list:8) */
extern void sw_marshal_VOID__BOXED_BOXED (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);

/* VOID:BOOLEAN,BOOLEAN,BOOLEAN (sw-marshals.list:9) */
extern void sw_marshal_VOID__BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                      GValue       *return_value,
                                                      guint         n_param_values,
                                                      const GValue *param_values,
                                                      gpointer      invocation_hint,
                                                      gpointer      marshal_data);

/* VOID:POINTER (sw-marshals.list:10) */
#define sw_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER

/* VOID:STRING,STRING,STRING,UINT,UINT,STRING,POINTER (sw-marshals.list:11) */
extern void sw_marshal_VOID__STRING_STRING_STRING_UINT_UINT_STRING_POINTER (GClosure     *closure,
                                                                            GValue       *return_value,
                                                                            guint         n_param_values,
                                                                            const GValue *param_values,
                                                                            gpointer      invocation_hint,
                                                                            gpointer      marshal_data);

/* VOID:STRING,STRING,STRING,INT64,STRING,STRING,UINT,UINT,STRING,POINTER (sw-marshals.list:12) */
extern void sw_marshal_VOID__STRING_STRING_STRING_INT64_STRING_STRING_UINT_UINT_STRING_POINTER (GClosure     *closure,
                                                                                                GValue       *return_value,
                                                                                                guint         n_param_values,
                                                                                                const GValue *param_values,
                                                                                                gpointer      invocation_hint,
                                                                                                gpointer      marshal_data);

/* VOID:STRING,BOXED,POINTER (sw-marshals.list:13) */
extern void sw_marshal_VOID__STRING_BOXED_POINTER (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

/* VOID:INT,INT,STRING (sw-marshals.list:14) */
extern void sw_marshal_VOID__INT_INT_STRING (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

/* VOID:STRING,UINT,STRING,BOXED,POINTER (sw-marshals.list:15) */
extern void sw_marshal_VOID__STRING_UINT_STRING_BOXED_POINTER (GClosure     *closure,
                                                               GValue       *return_value,
                                                               guint         n_param_values,
                                                               const GValue *param_values,
                                                               gpointer      invocation_hint,
                                                               gpointer      marshal_data);

G_END_DECLS

#endif /* __sw_marshal_MARSHAL_H__ */
